==> django-qr-toolkit-core-0.3.tar.gz: django-qr-toolkit-core-0.3/qrtoolkit_core/viewsets.py <==
from rest_framework.viewsets import GenericViewSet

from rest_framework import viewsets, mixins
from django_filters.rest_framework import DjangoFilterBackend, FilterSet, CharFilter, DateTimeFilter, NumberFilter

from .serializers import QRCodeSerializer, ApiHitSerializer, DepartmentSerializer, LinkUrlSerializer
from .models import ApiHit, QRCode, Department, LinkUrl


class CodeViewSet(viewsets.ModelViewSet):
    serializer_class = QRCodeSerializer
    queryset = QRCode.objects.order_by('-last_updated')
    filter_backends = (DjangoFilterBackend,)
    filterset_fields = ('mode', 'title', 'created', 'last_updated', 'uuid', 'department__name')


class ApiHitFilterSet(FilterSet):
    dept = CharFilter(field_name="code__department__name", lookup_expr='icontains', label='Department name')
    dept_id = NumberFilter(field_name='code__department__id', lookup_expr='exact', label='Department id')
    action = CharFilter(field_name='action', lookup_expr='icontains')
    hit_date = DateTimeFilter(field_name='hit_date')


class ApiHitViewSet(viewsets.ReadOnlyModelViewSet):
    serializer_class = ApiHitSerializer
    queryset = ApiHit.objects.all()
    pagination_class = None
    filter_backends = (DjangoFilterBackend,)
    filter_class = ApiHitFilterSet


class DepartmentViewSet(viewsets.ModelViewSet):
    serializer_class = DepartmentSerializer
    queryset = Department.objects.all()
    pagination_class = None
    filter_backends = (DjangoFilterBackend,)
    filterset_fields = ('name',)


class LinkUrlViewSet(mixins.CreateModelMixin,
                     mixins.RetrieveModelMixin,
                     mixins.UpdateModelMixin,
                     mixins.DestroyModelMixin,
                     GenericViewSet):
    serializer_class = LinkUrlSerializer
    queryset = LinkUrl.objects.all()
    pagination_class = None
    filter_backends = (DjangoFilterBackend,)
    filterset_fields = ('code',)

==> django-qr-toolkit-core-4.2.1.tar.gz: django-qr-toolkit-core-4.2.1/qrtoolkit_core/viewsets.py <==
from rest_framework.generics import GenericAPIView
from rest_framework.permissions import IsAuthenticated
from rest_framework.response import Response
from rest_framework.views import APIView
from rest_framework.viewsets import GenericViewSet

from rest_framework import viewsets, mixins, response
from django_filters.rest_framework import DjangoFilterBackend, FilterSet, CharFilter, DateTimeFilter, NumberFilter

from .serializers import QRCodeSerializer, ApiHitSerializer, DepartmentSerializer, LinkUrlSerializer, UserSerializer
from .models import ApiHit, QRCode, Department, LinkUrl


class CodeViewSet(viewsets.ModelViewSet):
    serializer_class = QRCodeSerializer
    queryset = QRCode.objects.order_by('-last_updated')
    filter_backends = (DjangoFilterBackend,)
    filterset_fields = ('mode', 'title', 'created', 'last_updated', 'uuid', 'department__name', 'short_uuid')


class ApiHitFilterSet(FilterSet):
    dept = CharFilter(field_name="code__department__name", lookup_expr='icontains', label='Department name')
    dept_id = NumberFilter(field_name='code__department__id', lookup_expr='exact', label='Department id')
    action = CharFilter(field_name='action', lookup_expr='icontains')
    hit_date = DateTimeFilter(field_name='hit_date')


class ApiHitViewSet(viewsets.ReadOnlyModelViewSet):
    serializer_class = ApiHitSerializer
    queryset = ApiHit.objects.all()
    pagination_class = None
    filter_backends = (DjangoFilterBackend,)
    filter_class = ApiHitFilterSet


class DepartmentViewSet(viewsets.ModelViewSet):
    serializer_class = DepartmentSerializer
    queryset = Department.objects.all()
    pagination_class = None
    filter_backends = (DjangoFilterBackend,)
    filterset_fields = ('name',)


class LinkUrlViewSet(mixins.CreateModelMixin,
                     mixins.RetrieveModelMixin,
                     mixins.UpdateModelMixin,
                     mixins.DestroyModelMixin,
                     GenericViewSet):
    serializer_class = LinkUrlSerializer
    queryset = LinkUrl.objects.all()
    pagination_class = None
    filter_backends = (DjangoFilterBackend,)
    filterset_fields = ('code',)


class UserViewSet(APIView):
    permission_classes = [IsAuthenticated, ]
    http_method_names = ['get', 'head', 'options']

    def get(self, request):
        serializer = UserSerializer(request.user)
        return Response(serializer.data)
